@@ -20,7 +20,7 @@
 #' @param options a list of the current chunk options
 #' @rdname hook_plot
 #' @return A character string (code with plot filenames wrapped)
-#' @references \url{http://yihui.name/knitr/hooks}
+#' @references \url{https://yihui.name/knitr/hooks/}
 #' @seealso \code{\link{hook_plot_custom}}
 #' @export
 #' @examples # this is what happens for a chunk like this
@@ -103,7 +103,7 @@ hook_plot_tex = function(x, options) {
     # If pic is standalone/first in set: open figure environment
     if (plot1) {
       pos = options$fig.pos
-      if (pos != '') pos = sprintf('[%s]', pos)
+      if (pos != '' && !grepl('^[[{]', pos)) pos = sprintf('[%s]', pos)
       fig1 = sprintf('\\begin{%s}%s', options$fig.env, pos)
     }
     # Add subfloat code if needed
@@ -191,7 +191,7 @@ hook_plot_tex = function(x, options) {
 .inline.hook.tex = function(x) {
   if (is.numeric(x)) {
     x = format_sci(x, 'latex')
-    i = grep('[^0-9.,]', x)
+    i = grep('[^-0-9.,]', x)
     x[i] = sprintf('\\ensuremath{%s}', x[i])
     if (getOption('OutDec') != '.') x = sprintf('\\text{%s}', x)
   }
@@ -236,7 +236,7 @@ hook_plot_tex = function(x, options) {
 #' @rdname output_hooks
 #' @return \code{NULL}; corresponding hooks are set as a side effect
 #' @export
-#' @references See output hooks in \url{http://yihui.name/knitr/hooks}.
+#' @references See output hooks in \url{https://yihui.name/knitr/hooks/}.
 #'
 #'   Jekyll and Liquid:
 #'   \url{https://github.com/jekyll/jekyll/wiki/Liquid-Extensions};
@@ -328,7 +328,7 @@ render_listings = function() {
 #'   you to use the default output hooks for LaTeX (not Sweave or listings), and
 #'   every figure/table environment must have a label.
 #' @export
-#' @references \url{http://yihui.name/knitr/hooks}
+#' @references \url{https://yihui.name/knitr/hooks/}
 #' @examples \dontrun{knit_hooks$set(document = hook_movecode)}
 #' # see example 103 at https://github.com/yihui/knitr-examples
 hook_movecode = function(x) {
